@@ -3,16 +3,16 @@ using namespace Rcpp;
 
 // [[Rcpp::export]]
 int anyOutside_int(IntegerVector x, int a, int b, bool nas_present = false, bool na_is_outside = true) {
-  int N = x.size();
+  const R_xlen_t N = x.size();
   if (nas_present) {
     if (na_is_outside) {
-      for (int i = 0; i < N; ++i) {
+      for (R_xlen_t i = 0; i < N; ++i) {
         if (x[i] == R_NaInt || x[i] < a || x[i] > b) {
           return ++i;
         }
       }
     } else {
-      for (int i = 0; i < N; ++i) {
+      for (R_xlen_t i = 0; i < N; ++i) {
         if (x[i] == R_NaInt) {
           continue;
         }
@@ -22,7 +22,7 @@ int anyOutside_int(IntegerVector x, int a, int b, bool nas_present = false, bool
       }
     }
   } else {
-    for (int i = 0; i < N; ++i) {
+    for (R_xlen_t i = 0; i < N; ++i) {
       if (x[i] < a || x[i] > b) {
         return ++i;
       }
@@ -33,16 +33,16 @@ int anyOutside_int(IntegerVector x, int a, int b, bool nas_present = false, bool
 
 // [[Rcpp::export]]
 int anyOutside_dbl(DoubleVector x, double a, double b, bool nas_present = false, bool na_is_outside = true) {
-  int N = x.size();
+  R_xlen_t N = x.size();
   if (nas_present) {
     if (na_is_outside) {
-      for (int i = 0; i < N; ++i) {
+      for (R_xlen_t i = 0; i < N; ++i) {
         if (R_IsNA(x[i]) || x[i] < a || x[i] > b) {
           return ++i;
         }
       }
     } else {
-      for (int i = 0; i < N; ++i) {
+      for (R_xlen_t i = 0; i < N; ++i) {
         if (R_IsNA(x[i])) {
           continue;
         }
@@ -53,7 +53,7 @@ int anyOutside_dbl(DoubleVector x, double a, double b, bool nas_present = false,
     }
   } else {
     // No NAs to check
-    for (int i = 0; i < N; ++i) {
+    for (R_xlen_t i = 0; i < N; ++i) {
       if (x[i] < a || x[i] > b) {
         return ++i;
       }
