@@ -3,8 +3,8 @@ using namespace Rcpp;
 
 // [[Rcpp::export]]
 int do_which_first(LogicalVector x) {
-  int N = x.size();
-  for (int i = 0; i < N; ++i) {
+  R_xlen_t N = x.size();
+  for (R_xlen_t i = 0; i < N; ++i) {
     if (x[i]) {
       return ++i;
     }
@@ -15,8 +15,8 @@ int do_which_first(LogicalVector x) {
 
 // [[Rcpp::export]]
 int do_which_last(LogicalVector x) {
-  int N = x.size();
-  for (int i = N - 1; i >= 0; --i) {
+  R_xlen_t N = x.size();
+  for (R_xlen_t i = N - 1; i >= 0; --i) {
     if (x[i]) {
       return ++i;
     }
@@ -27,8 +27,8 @@ int do_which_last(LogicalVector x) {
 
 // [[Rcpp::export]]
 int do_which_first_false (LogicalVector x) {
-  int N = x.size();
-  for (int i = 0; i < N; ++i) {
+  R_xlen_t N = x.size();
+  for (R_xlen_t i = 0; i < N; ++i) {
     if (!x[i]) {
       return ++i;
     }
@@ -42,8 +42,8 @@ int do_which_first_int_int (IntegerVector x,
                             bool eq = true,
                             bool gt = false,
                             bool lt = false) {
-  const int n = x.size();
-  const int m = y.size();
+  const R_xlen_t n = x.size();
+  const R_xlen_t m = y.size();
   if (n != m) {
     stop("lengths x and y differ.");
   }
@@ -52,7 +52,7 @@ int do_which_first_int_int (IntegerVector x,
   const int op = !(eq || gt || lt) ? 0 : (eq ? (gt ? 2 : (lt ? 3 : 1)) : (gt ? 4 : 5));
 
   // if (op == 0) {
-  //   for (int i = 0; i < n; ++i) {
+  //   for (R_xlen_t i = 0; i < n; ++i) {
   //     int xi = x[i];
   //     int yi = y[i];
   //     if (xi != yi) {
@@ -62,7 +62,7 @@ int do_which_first_int_int (IntegerVector x,
   //   return 0;
   // }
 
-  for (int i = 0; i < n; ++i) {
+  for (R_xlen_t i = 0; i < n; ++i) {
     switch (op) {
     case 0:
       if (x[i] != y[i]) {
